@@ -41,7 +41,7 @@ class ReplaceReferenceIni(ReplaceReference):
                 for src in self._config_value_sources(settings["env"], settings["section"], conf_args.env_name):
                     try:
                         if isinstance(src, SectionProxy):
-                            return self.loader.process_raw(self.conf, conf_args.env_name, src[key])
+                            return self._resolve_section_proxy(src, key, conf_args.env_name)
                         value = src.load(key, conf_args.chain)
                     except KeyError as exc:  # if fails, keep trying maybe another source can satisfy # noqa: PERF203
                         exception = exc
@@ -61,6 +61,18 @@ class ReplaceReferenceIni(ReplaceReference):
                     raise exception
         return None
 
+    def _resolve_section_proxy(self, src: SectionProxy, key: str, env_name: str | None) -> str:
+        """Resolve a key from a SectionProxy, returning empty string when factor filtering empties the value."""
+        try:
+            return self.loader.process_raw(self.conf, env_name, src[key])
+        except KeyError:
+            if key in src:
+                # Key exists but factor filtering emptied the value.
+                # For cross-section references this is a valid empty result,
+                # not a missing key — the caller explicitly asked for this value.
+                return ""
+            raise
+
     def _config_value_sources(
         self, env: str | None, section: str | None, current_env: str | None
     ) -> Iterator[SectionProxy | ConfigSet]:
